/// @brief[in] the vertex normal
varying vec3 fragmentNormal;
/// @brief the vertex in eye co-ordinates non homogeneous
varying vec3 eyeCord3;
/// @brief the number of lights enabled
uniform int numLightsEnabled;
/// @brief the eye position passed in from main app
uniform vec3 eye;

void pointLight(
								in int _light,
								in vec3 _normal,
								inout vec4 _ambient,
								inout vec4 _diffuse,
								inout vec4 _specular
							 )
{
	/// @brief normal . light direction
	float nDotVP;
	/// @brief normal . half vector
	float nDotHV;
	/// @brief the power factor
	float powerFactor;
	/// @brief the distance to the surface from the light
	float distance;
	/// @brief the direction from the surface to the light position
	vec3 VP;
	/// @brief halfVector the direction of maximum highlights
	vec3 halfVector;

	/// compute vector from surface to light position
	VP=vec3(gl_LightSource[_light].position)-eyeCord3;
	// get the distance from surface to light
	distance=length(VP);
	VP=normalize(VP);

	halfVector=normalize(VP+eye);
	// calculate the lambert term for the position vector
	nDotVP= max(0.0, dot(_normal,VP));
	// and for the half vector for specular
	nDotHV= max(0.0, dot(_normal, halfVector));

	// now see if we have any specular contribution
	if (nDotVP == 0.0)
	{
		powerFactor = 0.0; // no contribution
	}
	else
	{
		// here we raise the shininess value to the power of the half vector
		// Phong / Blinn shading method
		powerFactor = pow(nDotHV, gl_FrontMaterial.shininess);
	}
	// finally add the lighting contributions using the material properties
	_ambient+=gl_FrontMaterial.ambient*gl_LightSource[_light].ambient;
	// diffuse is calculated by n.v * colour
	_diffuse+=gl_FrontMaterial.diffuse*gl_LightSource[_light].diffuse*nDotVP;
	// compute the specular value
	_specular+=gl_FrontMaterial.specular*gl_LightSource[_light].specular*powerFactor;

}





void main ()
{
	vec4 ambient=vec4(0.0);
	vec4 diffuse=vec4(0.0);
	vec4 specular=vec4(0.0);

	pointLight(0,fragmentNormal,ambient,diffuse,specular);
	gl_FragColor = ambient+diffuse+specular;

}


